@@ -44,7 +44,6 @@ GdkPixbuf
 *screenshooter_capture_screenshot (gint     region,
                                    gint     delay,
                                    gboolean show_mouse,
-                                   gboolean show_border,
-                                   gboolean plugin);
+                                   gboolean show_border);
 
 #endif
