@@ -164,9 +164,6 @@ cb_button_clicked (GtkWidget *button, PluginData *pd)
   TRACE ("Start taking the screenshot");
 
   screenshooter_take_screenshot (pd->sd, TRUE);
-
-  /* Make the panel button clickable */
-  gtk_widget_set_sensitive (GTK_WIDGET (button), TRUE);
 }
 
 
@@ -327,6 +324,27 @@ set_panel_button_tooltip (PluginData *pd)
 
 
 
+/* Called when the screenshooter flow is finalized, successful or not
+action_executed: whether the action was executed successfully.
+data: what was defined in sd->finalize_callback_data, in this case PluginData is expected.
+*/
+static void
+cb_finalize (gboolean action_executed, gpointer data)
+{
+  PluginData *pd = data;
+
+  TRACE ("Execute finalize callback");
+
+  /* Make the panel button clickable */
+  gtk_widget_set_sensitive (GTK_WIDGET (pd->button), TRUE);
+
+  /* Update preferences if the action was executed successfully */
+  if (action_executed)
+    screenshooter_plugin_write_rc_file (pd->plugin, pd);
+}
+
+
+
 /* Create the plugin button */
 static void
 screenshooter_plugin_construct (XfcePanelPlugin *plugin)
@@ -351,17 +369,6 @@ screenshooter_plugin_construct (XfcePanelPlugin *plugin)
   TRACE ("Read the preferences file");
   screenshooter_plugin_read_rc_file (plugin, pd);
 
-  /* Check if the directory read from the preferences is valid */
-  if (G_UNLIKELY (!screenshooter_is_directory_writable (sd->screenshot_dir)))
-    {
-      g_free (pd->sd->screenshot_dir);
-      pd->sd->screenshot_dir = screenshooter_get_xdg_image_dir_uri ();
-    }
-
-  /* We want to take only one screenshot as in CLI, but not to close the main
-     loop after taking a screenshot */
-  pd->sd->plugin = TRUE;
-
   /* We want the actions dialog to be always displayed */
   pd->sd->action_specified = FALSE;
 
@@ -401,5 +408,9 @@ screenshooter_plugin_construct (XfcePanelPlugin *plugin)
   xfce_panel_plugin_menu_show_configure (plugin);
   g_signal_connect (plugin, "configure-plugin",
                     G_CALLBACK (cb_properties_dialog), pd);
+
+  /* Set the callback function */
+  pd->sd->finalize_callback = cb_finalize;
+  pd->sd->finalize_callback_data = pd;
 }
 XFCE_PANEL_PLUGIN_REGISTER (screenshooter_plugin_construct);
